==> bundle-tomcat-10.0.0.zip: sql/postgres/dropTables.sql <==
DROP TABLE IF EXISTS configuration;
DROP TABLE IF EXISTS arch_contract_data;
DROP TABLE IF EXISTS contract_data;
DROP TABLE IF EXISTS actormember;
DROP TABLE IF EXISTS actor;
DROP TABLE IF EXISTS processcategorymapping;
DROP TABLE IF EXISTS category;
DROP TABLE IF EXISTS arch_process_comment;
DROP TABLE IF EXISTS process_comment;
DROP TABLE IF EXISTS process_definition;
DROP TABLE IF EXISTS arch_document_mapping CASCADE;
DROP TABLE IF EXISTS document_mapping;
DROP TABLE IF EXISTS document;
DROP TABLE IF EXISTS arch_flownode_instance;
DROP TABLE IF EXISTS arch_process_instance;
DROP TABLE IF EXISTS arch_connector_instance;
DROP TABLE IF EXISTS arch_multi_biz_data;
DROP TABLE IF EXISTS arch_ref_biz_data_inst;
DROP TABLE IF EXISTS multi_biz_data;
DROP TABLE IF EXISTS ref_biz_data_inst;
DROP TABLE IF EXISTS pending_mapping;
DROP TABLE IF EXISTS connector_instance;
DROP TABLE IF EXISTS flownode_instance;
DROP TABLE IF EXISTS process_instance;
DROP TABLE IF EXISTS event_trigger_instance;
DROP TABLE IF EXISTS waiting_event;
DROP TABLE IF EXISTS message_instance;
DROP TABLE IF EXISTS processsupervisor;
DROP TABLE IF EXISTS business_app_menu;
DROP TABLE IF EXISTS business_app_page;
DROP TABLE IF EXISTS business_app;
DROP TABLE IF EXISTS command;
DROP TABLE IF EXISTS arch_data_instance;
DROP TABLE IF EXISTS data_instance;
DROP TABLE IF EXISTS dependencymapping;
DROP TABLE IF EXISTS dependency;
DROP TABLE IF EXISTS pdependencymapping;
DROP TABLE IF EXISTS pdependency;
DROP TABLE IF EXISTS external_identity_mapping;
DROP TABLE IF EXISTS user_membership;
DROP TABLE IF EXISTS custom_usr_inf_val;
DROP TABLE IF EXISTS custom_usr_inf_def;
DROP TABLE IF EXISTS user_contactinfo;
DROP TABLE IF EXISTS user_login;
DROP TABLE IF EXISTS user_;
DROP TABLE IF EXISTS role;
DROP TABLE IF EXISTS group_;
DROP TABLE IF EXISTS queriablelog_p;
DROP TABLE IF EXISTS queriable_log;
DROP TABLE IF EXISTS page;
DROP TABLE IF EXISTS blob_;
DROP TABLE IF EXISTS profilemember;
DROP TABLE IF EXISTS profile;
DROP TABLE IF EXISTS job_log;
DROP TABLE IF EXISTS job_param;
DROP TABLE IF EXISTS job_desc;
DROP TABLE IF EXISTS sequence;
DROP TABLE IF EXISTS tenant;
DROP TABLE IF EXISTS platform;
DROP TABLE IF EXISTS platformCommand;
DROP TABLE IF EXISTS form_mapping;
DROP TABLE IF EXISTS page_mapping;
DROP TABLE IF EXISTS process_content;
DROP TABLE IF EXISTS proc_parameter;
DROP TABLE IF EXISTS bar_resource;
DROP TABLE IF EXISTS temporary_content;
DROP TABLE IF EXISTS tenant_resource;
DROP TABLE IF EXISTS icon;

==> bundle-tomcat-10.3.0.zip: sql/postgres/dropTables.sql <==
DROP TABLE IF EXISTS configuration;
DROP TABLE IF EXISTS arch_contract_data;
DROP TABLE IF EXISTS contract_data;
DROP TABLE IF EXISTS actormember;
DROP TABLE IF EXISTS actor;
DROP TABLE IF EXISTS processcategorymapping;
DROP TABLE IF EXISTS category;
DROP TABLE IF EXISTS arch_process_comment;
DROP TABLE IF EXISTS process_comment;
DROP TABLE IF EXISTS process_definition;
DROP TABLE IF EXISTS arch_document_mapping CASCADE;
DROP TABLE IF EXISTS document_mapping;
DROP TABLE IF EXISTS document;
DROP TABLE IF EXISTS arch_flownode_instance;
DROP TABLE IF EXISTS arch_process_instance;
DROP TABLE IF EXISTS arch_connector_instance;
DROP TABLE IF EXISTS arch_multi_biz_data;
DROP TABLE IF EXISTS arch_ref_biz_data_inst;
DROP TABLE IF EXISTS multi_biz_data;
DROP TABLE IF EXISTS ref_biz_data_inst;
DROP TABLE IF EXISTS pending_mapping;
DROP TABLE IF EXISTS connector_instance;
DROP TABLE IF EXISTS flownode_instance;
DROP TABLE IF EXISTS process_instance;
DROP TABLE IF EXISTS event_trigger_instance;
DROP TABLE IF EXISTS waiting_event;
DROP TABLE IF EXISTS message_instance;
DROP TABLE IF EXISTS processsupervisor;
DROP TABLE IF EXISTS business_app_menu;
DROP TABLE IF EXISTS business_app_page;
DROP TABLE IF EXISTS business_app;
DROP TABLE IF EXISTS command;
DROP TABLE IF EXISTS arch_data_instance;
DROP TABLE IF EXISTS data_instance;
DROP TABLE IF EXISTS dependencymapping;
DROP TABLE IF EXISTS dependency;
DROP TABLE IF EXISTS pdependencymapping;
DROP TABLE IF EXISTS pdependency;
DROP TABLE IF EXISTS user_membership;
DROP TABLE IF EXISTS custom_usr_inf_val;
DROP TABLE IF EXISTS custom_usr_inf_def;
DROP TABLE IF EXISTS user_contactinfo;
DROP TABLE IF EXISTS user_login;
DROP TABLE IF EXISTS user_;
DROP TABLE IF EXISTS role;
DROP TABLE IF EXISTS group_;
DROP TABLE IF EXISTS queriable_log;
DROP TABLE IF EXISTS page;
DROP TABLE IF EXISTS profilemember;
DROP TABLE IF EXISTS profile;
DROP TABLE IF EXISTS job_log;
DROP TABLE IF EXISTS job_param;
DROP TABLE IF EXISTS job_desc;
DROP TABLE IF EXISTS sequence;
DROP TABLE IF EXISTS tenant;
DROP TABLE IF EXISTS platform;
DROP TABLE IF EXISTS platformCommand;
DROP TABLE IF EXISTS form_mapping;
DROP TABLE IF EXISTS page_mapping;
DROP TABLE IF EXISTS process_content;
DROP TABLE IF EXISTS proc_parameter;
DROP TABLE IF EXISTS bar_resource;
DROP TABLE IF EXISTS temporary_content;
DROP TABLE IF EXISTS tenant_resource;
DROP TABLE IF EXISTS icon;
DROP TABLE IF EXISTS arch_bpm_failure;
DROP TABLE IF EXISTS bpm_failure;
